@@ -123,7 +123,7 @@ BEGIN {
     eval {
 	require Test::Without::Module;
 	Test::Without::Module->import(
-	    My::Module::Recommend->optionals() );
+	    My::Module::Recommend->test_without() );
 	1;
     } or plan skip_all => 'Test::Without::Module not available';
 }
@@ -169,6 +169,10 @@ EOD
     return;
 }
 
+sub test_without {
+    return ( map { $_->test_without() } @optionals );
+}
+
 1;
 
 =head1 NAME
@@ -224,10 +228,17 @@ modules are installed. If any are not installed, a message is printed to
 standard error explaining the benefits to be gained from installing the
 module, and any possible problems with installing it.
 
+=head2 test_without
+
+ say for My::Module::Recommend->test_without();
+
+This static method simply returns the names of the modules to be tested
+without.
+
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -235,7 +246,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2018 by Thomas R. Wyant, III
+Copyright (C) 2014-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
